
.. currentmodule:: obspy.core.event
.. automodule:: obspy.core.event

    .. comment to end block

    Classes & Functions
    -------------------
    .. autosummary::
       :toctree: autogen
       :nosignatures:

       catalog.Catalog
       event.Event
       origin.Origin
       magnitude.Magnitude
       origin.Pick
       magnitude.Amplitude
       source.FocalMechanism
       source.MomentTensor

    .. comment to end block

    Modules
    -------
    .. autosummary::
       :toctree: autogen
       :nosignatures:

       base
       catalog
       event
       header
       magnitude
       origin
       source
       resourceid

    .. comment to end block
